@@ -18,19 +18,19 @@ import io
 from typing import Union,IO
 
 from .report_renderer import ReportRenderer
-from nf_presentation.renderers.compact_renderer import CompactRenderer
+from nf_presentation.renderers.compact_renderer import CompactRenderer,RenderOptions
 from .data_classes import TrainingInfo
 from . import assets
 
 
 def return_bytes(func):
     """a decorator that reads the created file objects and returns a bytes array to function standart return """
-    def callee(input_data:dict,output_file:Union[str,None] =  None):
+    def callee(*args,output_file:Union[str,None] =  None,**kwargs):
         #target_stream= output_file or io.BytesIO()
 
         with io.BytesIO() as stream:
 
-            func(input_data=input_data,output_file=stream)
+            func(*args,**kwargs,output_file=stream)
 
             stream.seek(0)
             data=stream.read()
@@ -75,7 +75,7 @@ def from_training(input_data:dict,output_file:Union[str,None] =  None):
         renderer.save(to=output_file)
 
 @return_bytes
-def from_single_exercise(input_data : Union[dict,str], output_file : Union[str,None]= None) -> bytes:
+def from_single_exercise(input_data : Union[dict,str], render_options: dict , output_file : Union[str,None]= None) -> bytes:
     """A function creating a pptx file from exercise object in Nanofootball API
     Arguments:
         input_data: dict | str
@@ -83,6 +83,16 @@ def from_single_exercise(input_data : Union[dict,str], output_file : Union[str,N
             dict - a dict-like object containing server request for making a pptx file
         output_file: str|None
             a destination for rendering pptx, may be a string for saving locally,
+        render_options: dict
+            a set of items to show or not show on the rendered scheme
+                ex. {
+                scheme_1=True,
+                scheme_2=True,
+                scheme_1_old=True
+                scheme_2_old=True,
+                video_1=True,
+                ...
+                }
 
     Output:
         Byte-array 
@@ -92,6 +102,24 @@ def from_single_exercise(input_data : Union[dict,str], output_file : Union[str,N
         with assets.get_exercise_test_data() as f:
             input_data=json.load(f)
 
-    renderer=CompactRenderer()
-    renderer.add_exercise_slide(exercise_data=input_data)
+    additional_params=[
+        'Этап подготовки',
+        'Часть тренировки',
+        'Тип упражнения',
+        'Продолжительность',
+        'Количество игроков',
+        'Организация',
+        'Пространство',
+        'Дозировка',
+        'Пульс',
+        'Касание мяча',
+        'Нейтральные',
+        'Расположение тренера',
+        'Выявление победителя'
+    ]
+
+    render_options=RenderOptions(render_options)
+    renderer=CompactRenderer(render_options=render_options)
+
+    renderer.add_exercise_slide(exercise_data=input_data,additional_params=additional_params)
     renderer.save(to=output_file)
\ No newline at end of file
